@@ -1,22 +1,20 @@
-package Pod::ProjectDocs::CSS;
+package Pod::ProjectDocs::CSS 0.46; # TRIAL
 
 use strict;
 use warnings;
 
-our $VERSION = '0.47.2'; # TRIAL VERSION
-
 use base qw/Pod::ProjectDocs::File/;
 use File::Basename;
 
 __PACKAGE__->default_name('podstyle.css');
 __PACKAGE__->data( do{ local $/; <DATA> } );
 
-sub relative_url {
+sub tag {
     my($self, $doc) = @_;
     my($name, $path) = fileparse $doc->get_output_path, qw/\.html/;
     my $relpath = File::Spec->abs2rel($self->get_output_path, $path);
     $relpath =~ s:\\:/:g if $^O eq 'MSWin32';
-    return $relpath;
+    return sprintf qq|<link rel="stylesheet" type="text/css" href="%s" />|, $relpath;
 }
 
 1;
