@@ -1,10 +1,8 @@
-package Pod::ProjectDocs::Doc;
+package Pod::ProjectDocs::Doc 0.46; # TRIAL
 
 use strict;
 use warnings;
 
-our $VERSION = '0.47.2'; # TRIAL VERSION
-
 use base qw/Pod::ProjectDocs::File/;
 use File::Basename;
 use File::Spec;
