@@ -1,10 +1,8 @@
-package Pod::ProjectDocs::DocManager;
+package Pod::ProjectDocs::DocManager 0.46; # TRIAL
 
 use strict;
 use warnings;
 
-our $VERSION = '0.47.2'; # TRIAL VERSION
-
 use base qw/Class::Accessor::Fast/;
 use File::Find;
 use IO::File;
