@@ -1,10 +1,8 @@
-package Pod::ProjectDocs::File;
+package Pod::ProjectDocs::File 0.46; # TRIAL
 
 use strict;
 use warnings;
 
-our $VERSION = '0.47.2'; # TRIAL VERSION
-
 use base qw/Class::Accessor::Fast Class::Data::Inheritable/;
 
 use IO::File;
