@@ -1,10 +1,8 @@
-package Pod::ProjectDocs::IndexPage;
+package Pod::ProjectDocs::IndexPage 0.46; # TRIAL
 
 use strict;
 use warnings;
 
-our $VERSION = '0.47.2'; # TRIAL VERSION
-
 use base qw/Pod::ProjectDocs::File/;
 use Pod::ProjectDocs::Template;
 
@@ -28,8 +26,8 @@ sub _get_data {
         desc     => $self->config->desc,
         lang     => $self->config->lang,
         json     => $self->json,
+        css      => $self->components->{css}->tag($self),
         charset  => 'UTF-8',
-        css_relative_url => $self->components->{css}->relative_url($self),
     };
     my $tt = Pod::ProjectDocs::Template->new;
     my $text = $tt->process($self, $self->data, $params);
@@ -38,12 +36,14 @@ sub _get_data {
 
 1;
 __DATA__
-<!DOCTYPE html>
-<html lang="[% lang %]" xml:lang="[% lang %]">
+<?xml version="1.0" encoding="[% charset %]"?>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
+   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="[% lang %]">
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=[% charset %]" />
 <title>[% title | html %]</title>
-<link rel="stylesheet" href="[% css_relative_url %]" type="text/css" />
+[% css %]
 <script type="text/javascript">
 //<![CDATA[
 var managers = [% json %];
@@ -88,7 +88,7 @@ function get_record_html (record, name, i) {
                    + record.path
                    + "'>"
                    + name + "</a></td><td width='99%'><small>"
-                   + (record.title || '')
+                   + record.title
                    + "</small></td></tr>";
     return row_html;
 }
@@ -115,8 +115,30 @@ function get_record_html (record, name, i) {
   </table>
 </div>
 
-<div id="list"></div>
+<div id="list">
+</div>
 
+[% FOREACH manager IN managers %]
+[% IF manager.docs.size %]
+<div class="box">
+<h2 class="t2">[% manager.desc | html %]</h2>
+  <table width="100%">
+    [% seq = 1 %]
+    [% FOREACH doc IN manager.docs %]
+    <tr class="[% IF seq mod 2 == 1 %]r[% ELSE %]s[% END %]">
+      <td nowrap="nowrap">
+        <a href="[% doc.relpath %]">[% doc.name | html %]</a>
+      </td>
+      <td width="99%">
+        <small>[% doc.title | html %]</small>
+      </td>
+    </tr>
+    [% seq = seq + 1 %]
+    [% END %]
+  </table>
+</div>
+[% END %]
+[% END %]
 <div class="footer">generated by <a href="http://search.cpan.org/perldoc?Pod%3A%3AProjectDocs">Pod::ProjectDocs</a></div>
 </body>
 </html>
