@@ -1,10 +1,8 @@
-package Pod::ProjectDocs::Template;
+package Pod::ProjectDocs::Template 0.46; # TRIAL
 
 use strict;
 use warnings;
 
-our $VERSION = '0.47.2'; # TRIAL VERSION
-
 use Template;
 use File::Basename;
 use File::Spec;
